@@ -34,15 +34,15 @@
 #include "eggtrayicon.h"
 
 #include "acme.h"
-#include "g-volume.h"
+#include "acme-volume.h"
 #ifdef USE_FBLEVEL
-#include "fb-level.h"
+#include "acme-fb-level.h"
 #endif
 
 typedef struct {
-	GVolume *volobj;
+	AcmeVolume *volobj;
 #ifdef USE_FBLEVEL
-	FBLevel *levobj;
+	AcmeFblevel *levobj;
 #endif
 	GladeXML *xml;
 	GtkWidget *dialog;
@@ -224,25 +224,13 @@ permission_problem_string (const char *files)
 				"the problem and restart ACME."), files);
 }
 
-static gboolean
-vol_problem_cb (GVolume *fb, gpointer data)
-{
-	char *msg;
-
-	msg = permission_problem_string ("/dev/mixer");
-	acme_error (msg);
-	g_free (msg);
-
-	return TRUE;
-}
-
 #ifdef USE_FBLEVEL
 static void
 fb_problem_cb (void)
 {
 	char *msg;
 
-	if (fb_level_is_powerbook () == FALSE)
+	if (acme_fblevel_is_powerbook () == FALSE)
 		return;
 
 	msg = permission_problem_string ("/dev/pmu");
@@ -263,7 +251,7 @@ update_use_pcm_cb (GConfClient *client, guint id, GConfEntry *entry,
 	use_pcm = gconf_client_get_bool (acme->conf_client,
 			"/apps/acme/use_pcm",
 			NULL);
-	g_volume_set_use_pcm (acme->volobj, use_pcm);
+	acme_volume_set_use_pcm (acme->volobj, use_pcm);
 }
 
 static void
@@ -628,6 +616,14 @@ about_activated (GtkMenuItem *menuitem, gpointer user_data)
 	gtk_widget_show(about);
 }
 
+static void
+quit_activated (GtkMenuItem *menuitem, gpointer user_date)
+{
+	exit(0);
+}
+
+
+
 static gboolean
 tray_icon_release (GtkWidget *widget, GdkEventButton *event, Acme *acme)
 {
@@ -698,6 +694,15 @@ init_tray (Acme *acme)
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (acme->popup_menu), item);
 
+	
+	item = gtk_image_menu_item_new_from_stock (GTK_STOCK_QUIT,
+                        NULL);
+	g_signal_connect (G_OBJECT (item), "activate",
+			G_CALLBACK(quit_activated), (gpointer) acme);
+	gtk_widget_show(item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (acme->popup_menu), item);      
+
+ 
 	gtk_container_add (GTK_CONTAINER (evbox), image);
 	gtk_container_add (GTK_CONTAINER (acme->tray_icon), evbox);
 	gtk_widget_show_all (GTK_WIDGET (acme->tray_icon));
@@ -743,6 +748,10 @@ dialog_show (Acme *acme)
 	int orig_x, orig_y, orig_w, orig_h, orig_d;
 	int screen_w, screen_h;
 	int x, y;
+	int pointer_x, pointer_y;
+	GdkScreen *pointer_screen;
+	GdkRectangle geometry;
+	int monitor;
 
 	gtk_window_set_screen (GTK_WINDOW (acme->dialog), acme->current_screen);
 	gtk_widget_realize (GTK_WIDGET (acme->dialog));
@@ -751,11 +760,29 @@ dialog_show (Acme *acme)
 				 &orig_x, &orig_y,
 				 &orig_w, &orig_h, &orig_d);
 
-	screen_w = gdk_screen_get_width (acme->current_screen);
-	screen_h = gdk_screen_get_height (acme->current_screen);
+	pointer_screen = NULL;
+	gdk_display_get_pointer (gdk_screen_get_display (acme->current_screen),
+				 &pointer_screen, &pointer_x,
+				 &pointer_y, NULL);
+	if (pointer_screen != acme->current_screen) {
+		/* The pointer isn't on the current screen, so just
+		 * assume the default monitor
+		 */
+		monitor = 0;
+	} else {
+		monitor =
+			gdk_screen_get_monitor_at_point (acme->current_screen,
+							 pointer_x, pointer_y);
+	}
+		
+	gdk_screen_get_monitor_geometry (acme->current_screen, monitor,
+					 &geometry);
 
-	x = (screen_w - orig_w) / 2;
-	y = screen_h / 2 + (screen_h / 2 - orig_h) / 2;
+	screen_w = geometry.width;
+	screen_h = geometry.height;
+
+	x = ((screen_w - orig_w) / 2) + geometry.x;
+	y = geometry.y + (screen_h / 2) + (screen_h / 2 - orig_h) / 2;
 
 	gdk_window_move (GTK_WIDGET (acme->dialog)->window, x, y);
 
@@ -988,19 +1015,19 @@ do_brightness_action (Acme *acme, int type)
 		acme->dialog_timeout = 0;
 	}
 
-	level = fb_level_get_level (acme->levobj);
+	level = acme_fblevel_get_level (acme->levobj);
 	acme_image_set (acme, ICON_BRIGHT);
 
 	switch (type) {
 	case BRIGHT_DOWN_KEY:
-		fb_level_set_level (acme->levobj, level - 1);
+		acme_fblevel_set_level (acme->levobj, level - 1);
 		break;
 	case BRIGHT_UP_KEY:
-		fb_level_set_level (acme->levobj, level + 1);
+		acme_fblevel_set_level (acme->levobj, level + 1);
 		break;
 	}
 
-	level = fb_level_get_level (acme->levobj);
+	level = acme_fblevel_get_level (acme->levobj);
 	progress = glade_xml_get_widget (acme->xml, "progressbar");
 	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress),
 			(double) level / 15);
@@ -1015,6 +1042,13 @@ do_sound_action (Acme *acme, int type)
 	GtkWidget *progress;
 	gboolean muted;
 	int vol;
+	int vol_step;
+
+	vol_step = gconf_client_get_int (acme->conf_client,
+			"/apps/acme/volume_step", NULL);
+
+	if (vol_step == 0)
+		vol_step = VOLUME_STEP;
 
 	if (acme->dialog_timeout != 0)
 	{
@@ -1022,35 +1056,35 @@ do_sound_action (Acme *acme, int type)
 		acme->dialog_timeout = 0;
 	}
 
-	vol = g_volume_get_volume (acme->volobj);
-	muted = g_volume_get_mute (acme->volobj);
+	vol = acme_volume_get_volume (acme->volobj);
+	muted = acme_volume_get_mute (acme->volobj);
 
 	switch (type) {
 	case MUTE_KEY:
-		g_volume_mute_toggle(acme->volobj);
+		acme_volume_mute_toggle(acme->volobj);
 		break;
 	case VOLUME_DOWN_KEY:
 		if (muted)
 		{
-			g_volume_mute_toggle(acme->volobj);
+			acme_volume_mute_toggle(acme->volobj);
 		} else {
-			g_volume_set_volume (acme->volobj, vol - VOLUME_STEP);
+			acme_volume_set_volume (acme->volobj, vol - vol_step);
 		}
 		break;
 	case VOLUME_UP_KEY:
 		if (muted)
 		{
-			g_volume_mute_toggle(acme->volobj);
+			acme_volume_mute_toggle(acme->volobj);
 		} else {
-			g_volume_set_volume (acme->volobj, vol + VOLUME_STEP);
+			acme_volume_set_volume (acme->volobj, vol + vol_step);
 		}
 		break;
 	}
 
-	muted = g_volume_get_mute(acme->volobj);
+	muted = acme_volume_get_mute(acme->volobj);
 	acme_image_set (acme, muted ? ICON_MUTED : ICON_LOUD);
 
-	vol = g_volume_get_volume (acme->volobj);
+	vol = acme_volume_get_volume (acme->volobj);
 	progress = glade_xml_get_widget (acme->xml, "progressbar");
 	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress),
 			(double) vol / 100);
@@ -1120,7 +1154,7 @@ do_action (int type, Acme *acme)
 		do_www_action (acme, "http://www.gnomedesktop.org");
 		break;
 	case CALCULATOR_KEY:
-		execute ("gnome-calculator", FALSE);
+		execute ("gcalctool", FALSE);
 		break;
 	case RECORD_KEY:
 		execute ("gnome-sound-recorder", FALSE);
@@ -1267,14 +1301,10 @@ main (int argc, char *argv[])
 	acme->dialog_timeout = 0;
 
 	/* initialise Volume handler */
-	acme->volobj = g_volume_new();
+	acme->volobj = acme_volume_new();
 	if (acme->volobj != NULL)
 	{
-		g_signal_connect(G_OBJECT(acme->volobj),
-				"fd_problem",
-				G_CALLBACK (vol_problem_cb), NULL);
-
-		g_volume_set_use_pcm (acme->volobj,
+		acme_volume_set_use_pcm (acme->volobj,
 				gconf_client_get_bool (acme->conf_client,
 					"/apps/acme/use_pcm", NULL));
 		gconf_client_notify_add (acme->conf_client,
@@ -1285,7 +1315,7 @@ main (int argc, char *argv[])
 
 #ifdef USE_FBLEVEL
 	/* initialise Frame Buffer level handler */
-	acme->levobj = fb_level_new();
+	acme->levobj = acme_fblevel_new();
 	if (acme->levobj == NULL)
 		fb_problem_cb ();
 #endif
